@@ -22,6 +22,11 @@
 #include <sys/filio.h>
 #endif
 
+#ifdef __CYGWIN__
+#include <sys/termios.h>
+#include <sys/socket.h>
+#endif
+
 #undef box
 #undef clear
 #undef erase
@@ -34,9 +39,9 @@
 #define normalcolor(c)          COLOR_PAIR(c)
 
 #ifdef LOCALES_HACK
-#define KT_DISP_FILTER(c)       ( ((c > ' ') && (c != '\177')) ? c : ' ' )
+#define KT_DISP_FILTER(c)       ( (((unsigned char) c > ' ') && (c != '\177')) ? c : ' ' )
 #else
-#define KT_DISP_FILTER(c)       (!iscntrl(c) ? c : ' ')
+#define KT_DISP_FILTER(c)       (!iscntrl((unsigned char) c) ? c : ' ')
 #endif
 
 #define VLINE           kintf_graph ? ACS_VLINE         : '|'
@@ -81,7 +86,7 @@ __KTOOL_BEGIN_C
 void kinterface();
 void kendinterface();
 
-int keypressed();
+int keypressed(bool wait = false);
 int emacsbind(int k);
 
 int getkey();
@@ -93,7 +98,6 @@ void kgotoxy(int x, int y);
 void hidecursor();
 void showcursor();
 void setbeep(int freq, int duration);
-void delay(int milisec);
 int kwherex();
 int kwherey();
 
