@@ -5,11 +5,13 @@
 #include "conscommon.h"
 #include "abstractui.h"
 
-__KTOOL_BEGIN_NAMESPACE
+enum textwindowtype {
+    TW_CENTERED = 2,
+    TW_NOBORDER = 4,
+    TW_SPACEBORDER = 8
+};
 
-#define TW_CENTERED     2
-#define TW_NOBORDER     4
-#define TW_SPACEBORDER  8
+__KTOOL_BEGIN_NAMESPACE
 
 class textwindow: public abstractuicontrol {
     private:
@@ -18,12 +20,13 @@ class textwindow: public abstractuicontrol {
 	
     public:
 	textwindow();
+	textwindow(const textwindow &aw);
 	textwindow(int xx1, int yy1, int xx2, int yy2, int wcolor,
 	    int noptions = 0, int tcolor = 0, const char *tfmt = 0, ...);
 	~textwindow();
 
-	void write(int x, int y, int c, const string text);
-	void write(int x, int y, const string text);
+	void write(int x, int y, int c, const string &text);
+	void write(int x, int y, const string &text);
 
 	void writef(int x, int y, int c, const char *fmt, ...);
 	void writef(int x, int y, const char *fmt, ...);
@@ -35,7 +38,7 @@ class textwindow: public abstractuicontrol {
 	void setcolor(int awc);
 	void setcoords(int x1, int y1, int x2, int y2);
 	void set_titlef(int color, const char *fmt, ...);
-	void set_title(int color, const string atitle);
+	void set_title(int color, const string &atitle);
 
 	void gotoxy(int x, int y);
 	void open();
