@@ -1,7 +1,7 @@
 /*
 *
 * kkconsui various textmode menus classes
-* $Id: cmenus.cc,v 1.17 2002/10/06 12:15:12 konst Exp $
+* $Id: cmenus.cc,v 1.20 2004/03/28 11:38:35 konst Exp $
 *
 * Copyright (C) 1999-2001 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -24,13 +24,15 @@
 
 #include "cmenus.h"
 
-verticalmenu::verticalmenu(int px1, int py1, int px2, int py2, int pncolor, int pscolor) {
+verticalmenu::verticalmenu(int px1, int py1, int px2, int py2, int pncolor, int pscolor)
+: abstractuicontrol() {
     initmembers();
     setcolor(pncolor, pscolor);
     setcoords(px1, py1, px2, py2);
 }
 
-verticalmenu::verticalmenu(int pncolor, int pscolor) {
+verticalmenu::verticalmenu(int pncolor, int pscolor)
+: abstractuicontrol() {
     initmembers();
     setcolor(pncolor, pscolor);
 }
@@ -257,6 +259,8 @@ int verticalmenu::open() {
 			    firstdisp = curelem - y2 + y1 + 1;
 			    intredraw();
 			} else {
+			    int savecurelem = curelem+1;
+
 			    while(curelem >= 0)
 			    if(!shownelem(curelem, 1)) {
 				curelem--;
@@ -264,6 +268,9 @@ int verticalmenu::open() {
 				break;
 			    }
 
+			    if(curelem < 0)
+				shownelem(curelem = savecurelem, 1);
+
 			    refresh();
 			}
 		    } else if(exitonedges) {
@@ -416,6 +423,25 @@ void verticalmenu::checkclear() {
 
 void verticalmenu::intredraw() {
     bool scf = clearonfocuslost;
+
+    if(curelem >= 0 && curelem < items.size()) {
+	vector<verticalmenuitem>::iterator ii;
+
+	for(ii = items.begin()+curelem; ii != items.end(); ii++) {
+	    if(ii->kind == ITEM_NORM) {
+		curelem = ii-items.begin();
+		break;
+	    }
+	}
+
+	for(ii = items.begin()+curelem; ii != items.begin(); ii--) {
+	    if(ii->kind == ITEM_NORM) {
+		curelem = ii-items.begin();
+		break;
+	    }
+	}
+    }
+
     clearonfocuslost = false;
     redraw();
     clearonfocuslost = scf;
@@ -454,8 +480,10 @@ int horizontalmenu::menu_otherkeys(verticalmenu &ref, int k) {
 	case KEY_LEFT  : return HM_LEFT;
 	case KEY_F(10) : return HM_CLOSE;
 	default:
-	    currenthmenu->finished = currenthmenu->otherkeys(*currenthmenu, k);
-	    return currenthmenu->finished ? 0 : -1;
+	    if(currenthmenu->otherkeys) {
+		currenthmenu->finished = currenthmenu->otherkeys(*currenthmenu, k);
+		return currenthmenu->finished ? 0 : -1;
+	    }
     }
 
     return -1;
