@@ -7,7 +7,7 @@
 
 static fileselector *instance;
 
-fileselector::fileselector() {
+fileselector::fileselector(): idle(0), otherkeys(0) {
 }
 
 fileselector::~fileselector() {
@@ -134,7 +134,6 @@ void fileselector::exec() {
 			    setdcurrent = justfname(di.dirname.substr(0,
 				di.dirname.size()-1));
 
-			    chdir("..");
 			    dcurrent = getcwd(buf, 511);
 			}
 		    } else {
@@ -169,6 +168,8 @@ void fileselector::close() {
 void fileselector::menuidle(verticalmenu &m) {
     if(instance->idle) {
 	(*(instance->idle))(*instance);
+    } else {
+	keypressed(true);
     }
 }
 
@@ -182,14 +183,20 @@ int fileselector::menukeys(verticalmenu &m, int k) {
 
     switch(k) {
 	case ' ':
-	    if(instance->options & FSEL_DIRSELECT) {
+	    if((instance->options & FSEL_DIRSELECT)
+	    || (instance->options & FSEL_MULTI)) {
 		if(i) {
 		    if(i->fname != "..") {
-			instance->selected.push_back(instance->dcurrent + i->fname);
+			if(!(instance->options & FSEL_MULTI) || instance->selected.empty())
+			    instance->selected.push_back(instance->dcurrent + i->fname);
+
 			instance->finish = true;
-			return m.getpos()+1;
 		    }
 		}
+
+		if(instance->finish)
+		    return m.getpos()+1;
+
 	    }
 	    break;
 
