@@ -1,7 +1,7 @@
 /*
 *
 * kkstrtext string related and text processing routines
-* $Id: kkstrtext.cc,v 1.38 2004/06/24 08:31:22 konst Exp $
+* $Id: kkstrtext.cc,v 1.45 2005/02/01 00:13:24 konst Exp $
 *
 * Copyright (C) 1999-2004 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -890,6 +890,9 @@ string siconv(const string &atext, const string &fromcs, const string &tocs) {
 	size_t inleft, outleft, soutleft;
 	char *inbuf, *outbuf, *sinbuf, *soutbuf;
 
+	//from iconv.c (libiconv)
+	iconv(cd,NULL,NULL,NULL,NULL);
+
 	while(!text.empty()) {
 	    sinbuf = inbuf = strdup(text.c_str());
 	    inleft = strlen(inbuf);
@@ -1047,14 +1050,14 @@ char *str_to_utf8(const char *pin) {
     return result;
 }
 
-string striprtf(const string &s) {
-    string r, spec;
+string striprtf(const string &s, const string &charset) {
+    string r, spec, unichar, tmp;
     char pre = 0;
-    bool bprint, bspec;
+    bool bprint, bspec, bunicode;
     int bparen = -1;
 
     bprint = true;
-    bspec = false;
+    bspec = bunicode = false;
 
     for(string::const_iterator i = s.begin(); i != s.end(); ++i) {
 	if(!isalpha(*i) && !isdigit(*i)) bprint = true;
@@ -1096,19 +1099,54 @@ string striprtf(const string &s) {
 		} else {
 		    bprint = true;
 		    r += *i;
+		    pre = 0;
+		    continue;
 		}
 		break;
 
 	    case '\'':
-		if(pre == '\\') {
+		if(!bparen && bprint && pre == '\\') {
 		    spec = "";
 		    bspec = true;
+		} else {
+		    r += *i;
 		}
 		break;
 
+	    case 'u':
+		if(!bparen) {
+		    if(pre == '\\' && isdigit(*(i+1))) {
+			unichar = "";
+			bunicode = true;
+		    } else if(bprint) {
+			r += *i;
+		    }
+		}
+		break;
 	    default:
-		if(bprint && !bparen) {
-		    r += *i;
+		if(!bparen) {
+		    if(bunicode) {
+			unichar += *i;
+
+			if(unichar.size() == 5) {
+			    bunicode = false;
+			    if(unichar.substr(0, 4).find_first_not_of("0123456789") == -1) {
+				long l = strtol(unichar.substr(0, 4).c_str(), 0, 0);
+				char ubuf[sizeof(long)+4];
+			    #ifdef HAVE_ICONV
+				memcpy(ubuf, "\xff\xfe", 2);
+				memcpy(ubuf+2, &l, sizeof(long));
+				memcpy(ubuf+sizeof(long)*2, "\x0a\x00", 2);
+			    #else
+				strcpy(ubuf, unichar.substr(4).c_str());
+			    #endif
+				r += siconv(ubuf , "utf-16", charset);
+			    }
+			}
+
+		    } else if(bprint) {
+			r += *i;
+		    }
 		}
 	}
 
