@@ -136,11 +136,16 @@ void motorconfiguration::readuserdetails() {
     int npos;
     struct passwd *p;
 
-    if(p = getpwuid(getuid()))
-    if(p->pw_gecos) {
-	userfullname = p->pw_gecos;
-	if((npos = userfullname.find(",")) != -1)
-	    userfullname.erase(npos);
+    if(p = getpwuid(getuid())) {
+	if(p->pw_gecos) {
+	    userfullname = p->pw_gecos;
+	    if((npos = userfullname.find(",")) != -1)
+		userfullname.erase(npos);
+	}
+
+	if(p->pw_name && userfullname.empty()) {
+	    userfullname = p->pw_name;
+	}
     }
 }
 
