@@ -76,12 +76,22 @@ bool motordebugger::getfreeterm() {
 	}
     }
 
-    if(r)
-    if(r = !access(termname.c_str(), W_OK)) {
-	f.open((project.getrootdir() + "/.debugtty").c_str());
-	if(f.is_open()) {
-	    f << termname << endl;
-	    f.close();
+    if(r) {
+	struct stat st;
+
+	if(!stat(termname.c_str(), &st))
+	if(st.st_mode & S_IFLNK) {
+	    auto_ptr<char> rlbuf(new char[64]);
+	    if(!readlink(termname.c_str(), rlbuf.get(), 512))
+		termname = rlbuf.get();
+	}
+
+	if(r = !access(termname.c_str(), W_OK)) {
+	    f.open((project.getrootdir() + "/.debugtty").c_str());
+	    if(f.is_open()) {
+		f << termname << endl;
+		f.close();
+	    }
 	}
     }
 
@@ -188,7 +198,7 @@ void motordebugger::launch(debuggercommand::commandkind akind) {
 
 	if(factive) {
     	    frunning = true;
-	    ui.logf(_("Running %s.."), project.getname().c_str());
+	    ui.logf(_("Running %s.. Ctrl-C to break"), project.getname().c_str());
 	    setbreakpoints();
 	    setparser("args", project.getarguments());
 	    exec(akind);
@@ -226,7 +236,7 @@ void motordebugger::cont() {
         if(!frunning) {
             run();
         } else {
-	    ui.logf(_("Continuing running %s.."), project.getname().c_str());
+	    ui.logf(_("Continuing running %s.. Ctrl-C to break"), project.getname().c_str());
 	    exec(debuggercommand::cont);
         }
     }
@@ -245,7 +255,7 @@ void motordebugger::gonext(debuggercommand::commandkind akind) {
 //	    launch(debuggercommand::run);
 	    launch(debuggercommand::breakmain);
         } else {
-	    ui.logf(_("Continuing running %s.."), project.getname().c_str());
+	    ui.logf(_("Continuing running %s.. Ctrl-C to break"), project.getname().c_str());
 
             do {
 
