@@ -1,9 +1,6 @@
 #include "parserule.h"
 
-#include <regex.h>
-
-parserule::parserule() {
-}
+#include <iostream>
 
 parserule::parserule(const string &atarget, const string &amask, messagekind akind) {
     string tmbuf;
@@ -12,6 +9,7 @@ parserule::parserule(const string &atarget, const string &amask, messagekind aki
     target = atarget;
     kind = akind;
     tmbuf = mask = amask;
+    rexcompiled = false;
 
     porder = getrword(mask);
     if(porder.find_first_not_of("INKLFDEW") != -1) {
@@ -26,24 +24,35 @@ parserule::parserule(const string &atarget, const string &amask, messagekind aki
     }
 }
 
+parserule::parserule(const parserule &p) {
+    mask = p.mask;
+    porder = p.porder;
+    target = p.target;
+    kind = p.kind;
+    rexcompiled = false;
+}
+
 parserule::~parserule() {
+    if(rexcompiled) {
+	regfree(&rex);
+    }
 }
 
 bool parserule::exec(const string &buf) const {
-    regex_t r;
-    regmatch_t rm[10];
     bool ret = false;
     int i;
+    regmatch_t rexm[10];
 
-    if(!regcomp(&r, mask.c_str(), REG_EXTENDED)) {
-	if(ret = !regexec(&r, buf.c_str(), 10, rm, 0)) {
+    if(!rexcompiled)
+	rexcompiled = !regcomp(&rex, mask.c_str(), REG_EXTENDED);
+
+    if(ret = rexcompiled) {
+	if(ret = !regexec(&rex, buf.c_str(), 10, rexm, 0)) {
             values.clear();
-	    for(i = 1; (i < 10) && (rm[i].rm_so != -1); i++)
-	        values.push_back(buf.substr(rm[i].rm_so,
-                    rm[i].rm_eo-rm[i].rm_so));
+	    for(i = 1; (i < 10) && (rexm[i].rm_so != -1); i++)
+	        values.push_back(buf.substr(rexm[i].rm_so,
+                    rexm[i].rm_eo-rexm[i].rm_so));
         }
-
-	regfree(&r);
     }
 
     return ret;
