@@ -3,6 +3,8 @@
 
 #include "motorcommon.h"
 
+#include <regex.h>
+
 __MOTOR_BEGIN_NAMESPACE
 
 class parserule {
@@ -20,12 +22,15 @@ class parserule {
 	string target;
 	    // associated make target
 
+	mutable regex_t rex;
+	mutable bool rexcompiled;
+
 	messagekind kind;
 	mutable vector<string> values;
 
     public:
-	parserule();
 	parserule(const string &atarget, const string &amask, messagekind kind = info);
+	parserule(const parserule &p);
 	~parserule();
 
 	bool exec(const string &buf) const;
