@@ -32,8 +32,9 @@ int main(int argc, char **argv) {
     * motor has to be multi-lingual by default.
     */
 #ifdef ENABLE_NLS
-    bindtextdomain("motor", LOCALE_DIR);
-    textdomain("motor");
+    setlocale(LC_ALL, "");
+    bindtextdomain(PACKAGE, LOCALE_DIR);
+    textdomain(PACKAGE);
 #endif
 
     conf.load();
