@@ -14,8 +14,15 @@ class motorfile {
 	    project
 	};
 
+	struct build {
+	    build(): def(false) {}
+	    string param, help;
+	    bool def;
+	};
+
     protected:
 	string fname;
+	build fbuild;
 
     public:
 	motorfile(const string &afname);
@@ -23,6 +30,9 @@ class motorfile {
 
 	string getfname() const;
 
+	build getbuild() const { return fbuild; }
+	void setbuild(const build &b) { fbuild = b; }
+
 	void remove();
 	    // removes the file from disk
 
