@@ -6,8 +6,8 @@
 projectdebug::projectdebug() {
 }
 
-projectdebug::projectdebug(const string &pname) {
-    load(pname);
+projectdebug::projectdebug(const projectname aname) {
+    load(aname);
 }
 
 projectdebug::~projectdebug() {
@@ -34,8 +34,9 @@ bool projectdebug::load(const projectname aname) {
     bpoints.clear();
     watches.clear();
 
-    projectname::absorb(aname);
-    df.open((conf.gettemplatedir(gettemplatename()) + "/Debug").c_str());
+//    projectname::absorb(aname);
+    pname = aname;
+    df.open((conf.gettemplatedir(pname.gettemplatename()) + "/Debug").c_str());
 
     if(ret = df.is_open()) {
 	while(getconf(sect, buf, df)) {
@@ -90,7 +91,7 @@ bool projectdebug::load(const projectname aname) {
     }
 
     df.clear();
-    df.open(getfname().c_str());
+    df.open(pname.getregfname().c_str());
 
     if(df.is_open()) {
 	while(getconf(sect, buf, df)) {
