@@ -17,7 +17,10 @@ __MOTOR_BEGIN_NAMESPACE
 *
 */
 
-class projectdebug: virtual public projectname {
+class projectdebug/*: virtual public projectname*/ {
+    private:
+	projectname pname;
+
     public:
 	enum debuggermode {
 	    dm_normal,
@@ -39,7 +42,7 @@ class projectdebug: virtual public projectname {
 
     public:
 	projectdebug();
-	projectdebug(const string &pname);
+	projectdebug(const projectname aname);
 	~projectdebug();
 
 	vector<string> getdebuginit() const;
