@@ -13,7 +13,10 @@ __MOTOR_BEGIN_NAMESPACE
 *
 */
 
-class projectdesk: virtual public projectname {
+class projectdesk/*: virtual public projectname*/ {
+    private:
+	projectname pname;
+
     protected:
 	string arguments;
 	vector< pair<string, string> > settings;
@@ -23,7 +26,7 @@ class projectdesk: virtual public projectname {
 
     public:
 	projectdesk();
-	projectdesk(const string &pname);
+	projectdesk(const projectname aname);
 	~projectdesk();
 
 	string getarguments() const;
