@@ -13,7 +13,10 @@ __MOTOR_BEGIN_NAMESPACE
 *
 */
 
-class projectfiles: virtual public projectname {
+class projectfiles/*: virtual public projectname*/ {
+    private:
+	projectname pname;
+
     protected:
 	vector<motorfolder> folders;
 
