@@ -18,16 +18,18 @@ class projectname {
 	bool loaded, fmodified;
 
     protected:
-	void setmodified(bool exp = true);
 	void clear();
+	bool convert4();
 
     public:
 	projectname();
 	projectname(const string &pname/*, const string revision*/);
 	~projectname();
 
+	void setmodified(bool exp = true);
+
 	virtual string getname() const;
-	virtual string getfname() const;
+	virtual string getregfname() const;
 	virtual string getversion() const;
 	virtual string gettemplatename() const;
 //	virtual const string getrevision() const;
