@@ -5,8 +5,8 @@
 projectpaths::projectpaths() {
 }
 
-projectpaths::projectpaths(const string &pname) {
-    load(pname);
+projectpaths::projectpaths(const projectname aname) {
+    load(aname);
 }
 
 projectpaths::~projectpaths() {
@@ -29,21 +29,21 @@ string projectpaths::getvcsroot() const {
 }
 
 void projectpaths::setvcsmodule(const string &avcsmodule, const string &avcsrevision) {
-    setmodified(vcsmodule != avcsmodule || vcsrevision != avcsrevision);
+    pname.setmodified(vcsmodule != avcsmodule || vcsrevision != avcsrevision);
 
     vcsmodule = avcsmodule;
     vcsrevision = avcsrevision;
 }
 
 void projectpaths::setvcsroot(const string &avcsroot) {
-    setmodified(vcsroot != avcsroot);
+    pname.setmodified(vcsroot != avcsroot);
     vcsroot = avcsroot;
 }
 
 void projectpaths::setrootdir(const string &arootdir) {
     char buf[512];
 
-    setmodified(rootdir != arootdir);
+    pname.setmodified(rootdir != arootdir);
     rootdir = arootdir;
 
     if(!chdir(rootdir.c_str()))
@@ -53,20 +53,24 @@ void projectpaths::setrootdir(const string &arootdir) {
 bool projectpaths::load(const projectname aname) {
     ifstream f;
     string sect, buf;
+    char cbuf[512];
     bool ret;
 
-    projectname::absorb(aname);
-    f.open(getfname().c_str());
+//    projectname::absorb(aname);
+    pname = aname;
+    f.open(pname.getregfname().c_str());
 
     if(ret = f.is_open()) {
 	while(getconf(sect, buf, f) &&
 	(rootdir.empty() || vcsmodule.empty() || vcsroot.empty())) {
-    	    if(sect == "rootdir") setrootdir(buf); else
     	    if(sect == "vcsmodule") vcsmodule = buf; else
     	    if(sect == "vcsroot") vcsroot = buf;
 	}
 
 	f.close();
+
+	if(readlink(pname.getregfname().c_str(), cbuf, 512) > 0)
+	    setrootdir(justpathname(cbuf));
     }
 
     return ret;
