@@ -6,7 +6,10 @@
 
 __MOTOR_BEGIN_NAMESPACE
 
-class projectpaths: virtual public projectname {
+class projectpaths {
+    private:
+	projectname pname;
+
     public:
 	enum fnamemode {
 	    relative, absolute
@@ -18,7 +21,7 @@ class projectpaths: virtual public projectname {
 
     public:
 	projectpaths();
-	projectpaths(const string &pname);
+	projectpaths(const projectname aname);
 	~projectpaths();
 
 	string getrootdir() const;
@@ -29,6 +32,7 @@ class projectpaths: virtual public projectname {
 	void setvcsmodule(const string &avcsmodule, const string &avcsrevision = "");
 	void setvcsroot(const string &avcsroot);
 	void setrootdir(const string &arootdir);
+	string getprojfname() const;
 
 	string transformfname(fnamemode mode, const string &fname) const;
 
