@@ -15,13 +15,18 @@ __MOTOR_BEGIN_NAMESPACE
 *
 */
 
-class projecttempl: virtual public projectname {
+class projecttempl/*: virtual public projectname*/ {
+    private:
+	projectname pname;
+
     protected:
 	vector<parserule> parserules;
 	vector<sourcetemplate> sourcetemplates;
 	vector<motordist> dists;
 	vector< pair<char, string> > tagnames;
 
+//	void clear();
+
     public:
 	projecttempl();
 	projecttempl(const projectname aname);
@@ -36,6 +41,9 @@ class projecttempl: virtual public projectname {
 	vector<motordist>::const_iterator distbegin() const;
 	vector<motordist>::const_iterator distend() const;
 
+	vector< pair<char, string> >::const_iterator tagnamebegin() const;
+	vector< pair<char, string> >::const_iterator tagnameend() const;
+
 	bool load(const projectname aname);
 
 	void populateparselist(pparamslist *parselist);
