@@ -11,7 +11,7 @@ motortagbrowser::motortagbrowser()
 motortagbrowser::~motortagbrowser() {
 }
 
-vector<motortagbrowser::record> motortagbrowser::fetch(const string &prefix) {
+vector<motortagbrowser::record> motortagbrowser::fetch(const string &prefix, const string &filter) {
     vector<record> r;
     vector<record>::iterator ir;
 
@@ -19,7 +19,8 @@ vector<motortagbrowser::record> motortagbrowser::fetch(const string &prefix) {
 
     for(ir = tags.begin(); ir != tags.end(); ir++)
 	if(prefix == ir->getname().substr(0, prefix.size()))
-	    r.push_back(*ir);
+	    if(filter.find(ir->getkind()) != -1)
+		r.push_back(*ir);
 
     return r;
 }
@@ -109,6 +110,10 @@ string motortagbrowser::record::getinfo() const {
     return info;
 }
 
+char motortagbrowser::record::getkind() const {
+    return kind;
+}
+
 string motortagbrowser::record::getbrowsertagname() const {
     return project.getbrowsertagname(kind);
 }
