@@ -30,6 +30,7 @@ class motortagbrowser {
 		string getname() const;
 		string getinfo() const;
 		string getbrowsertagname() const;
+		char getkind() const;
 	};
 
     private:
@@ -44,7 +45,7 @@ class motortagbrowser {
 	motortagbrowser();
 	~motortagbrowser();
 
-	vector<record> fetch(const string &prefix = "");
+	vector<record> fetch(const string &prefix = "", const string &filter = "");
 
 	void setscope(viewscope ascope);
 	viewscope getscope() const;
