@@ -112,6 +112,10 @@ void motorui::setoutputblockmode(bool fblock) {
     outputblocked = fblock;
 }
 
+motorui::askresult motorui::notemplate(string &templname) const {
+    return motorui::no;
+}
+
 // ----------------------------------------------------------------------------
 
 motorui::editfile::editfile(): x(0), y(0) {
