@@ -23,6 +23,8 @@ ncursesui thisui;
 #define LOOKER_HEIGHT		(LINES-2)
 #define OUTLINES_LIMIT		512
 
+#define getcolor(c)	uiconf.getcolor(c)
+
 ncursesui::ncursesui(): terminate(false), outopen(false) {
 }
 
@@ -267,6 +269,59 @@ void ncursesui::usage() {
     "\t-h, --help\tdisplay this help screen" << endl;
 }
 
+bool ncursesui::regproject() {
+    bool r = false;
+    string fname, pname, lfname, postfix = ".motor";
+    char buf[512];
+
+    if(input(motorui::file, fname, _("add project to the registry: ")) == motorui::yes) {
+	if(!access(fname.c_str(), R_OK)) {
+	    pname = justfname(fname);
+
+	    if(pname.size() > postfix.size())
+	    if(pname.substr(pname.size()-postfix.size()) == postfix)
+		pname.erase(pname.size()-postfix.size());
+
+	    if(pname != justfname(fname)) {
+		bool updname = false;
+
+		while(!pname.empty() && !projectname(pname).empty()) {
+		    updname = true;
+		    sprintf(buf, _("Already registered! Rename %s (%s) to: "),
+			pname.c_str(), justfname(fname).c_str());
+		    if(input(text, pname, buf) != motorui::yes)
+			pname = "";
+		}
+
+		if(!pname.empty()) {
+		    if(updname) {
+			string nfname = justpathname(fname) + "/" + pname + postfix;
+			rename(fname.c_str(), nfname.c_str());
+			fname = nfname;
+		    }
+
+		    lfname = conf.getprojectdir() + pname;
+		    symlink(fname.c_str(), lfname.c_str());
+
+		    motorproject np(pname);
+		    r = !np.empty();
+		    if(!r) {
+			logf(_("~%s~ is not a motor project"), justfname(fname).c_str());
+			unlink(lfname.c_str());
+		    }
+		}
+	    } else {
+		logf(_("~%s~ is an invalid name for a motor project file"));
+	    }
+
+	} else {
+	    logf(_("Cannot access ~%s~"), justfname(fname).c_str());
+	}
+    }
+
+    return r;
+}
+
 const projectname ncursesui::selectproject(mgrmode amode, vector<string> templs) {
     vector<projectname>::iterator i;
     vector<projectname> pnames;
@@ -283,12 +338,12 @@ const projectname ncursesui::selectproject(mgrmode amode, vector<string> templs)
 
     if(amode == selectorcreate) {
 	db.setbar(new horizontalbar(getcolor(cp_menu), getcolor(cp_menusel),
-    	    _("Add"), _("Remove"), _("Open"), 0));
+    	    _("Create/Import.."), _("Add"), _("Remove"), _("Open"), 0));
 
-	db.addkey(KEY_IC, 0);
-	db.addkey(KEY_DC, 1);
+	db.addkey(KEY_IC, 1);
+	db.addkey(KEY_DC, 2);
 
-        db.getbar()->item = 2;
+        db.getbar()->item = 3;
 
 	db.setwindow(new textwindow(0, 0, (int) (DIALOG_WIDTH*0.8),
     	    DIALOG_HEIGHT, getcolor(cp_menufr), TW_CENTERED,
@@ -338,11 +393,11 @@ const projectname ncursesui::selectproject(mgrmode amode, vector<string> templs)
             if(iterfirst) tree.setcur(lpid);
 	}
 
-        if(tree.empty() && (amode == selectorcreate)) {
+/*        if(tree.empty() && (amode == selectorcreate)) {
             if(iterfirst) baritem = 0; else break;
-        } else {
+        } else {*/
             if(!db.open(menuitem, baritem, (void **) &j)) break;
-        }
+//        }
 
         iterfirst = false;
 
@@ -356,6 +411,10 @@ const projectname ncursesui::selectproject(mgrmode amode, vector<string> templs)
 		}
 	        break;
 	    case 1:
+		if(regproject())
+		    tree.clear();
+		break;
+	    case 2:
 		if(j) {
 		    mp = motorproject(pnames[j-1], LP_NOCHECK);
 
@@ -366,7 +425,7 @@ const projectname ncursesui::selectproject(mgrmode amode, vector<string> templs)
 		    }
 		}
 	        break;
-	    case 2:
+	    case 3:
 		if(j) {
 		    pname = pnames[j-1];
 		}
@@ -378,7 +437,7 @@ const projectname ncursesui::selectproject(mgrmode amode, vector<string> templs)
     return pname;
 }
 
-string ncursesui::selecttemplate(const string &def) {
+string ncursesui::selecttemplate(const string &def, const string &title) const {
     dialogbox db;
     string ret, lw, buf;
     int n, b, nnode, citem, id, cpid = -1;
@@ -390,8 +449,7 @@ string ncursesui::selecttemplate(const string &def) {
     tlist = manager.gettemplatelist();
 
     db.setwindow(new textwindow(0, 0, DIALOG_WIDTH, DIALOG_HEIGHT,
-	getcolor(cp_menufr), TW_CENTERED, getcolor(cp_menuhl),
-	_(" Templates available ")));
+	getcolor(cp_menufr), TW_CENTERED, getcolor(cp_menuhl), title.c_str()));
     db.settree(new treeview(getcolor(cp_menu), getcolor(cp_menusel),
 	getcolor(cp_menu), getcolor(cp_menu)));
 
@@ -429,10 +487,6 @@ string ncursesui::selecttemplate(const string &def) {
     return ret;
 }
 
-int ncursesui::getcolor(int n) {
-    return uiconf.getcolor(n);
-}
-
 void ncursesui::mainloop() {
     while(!terminate) {
         workareaupdate();
@@ -1123,6 +1177,18 @@ bool ncursesui::editcloseall() {
     return ret;
 }
 
+bool ncursesui::changetemplate() {
+    string nt = selecttemplate(project.gettemplatename());
+
+    if(!nt.empty() && nt != project.gettemplatename())
+    if(ask("NY", _("Warning: changing template will rearrange files in project. Proceed?")) == motorui::yes) {
+	project.settemplate(nt);
+	return true;
+    }
+
+    return false;
+}
+
 void ncursesui::populatesettingstree(treeview &tree) {
     string cflags, lflags;
 
@@ -1185,18 +1251,12 @@ bool ncursesui::projectsettings() {
 		break;
 
             case 11:
-//		changetemplate();
+		if(changetemplate())
+		    rc = true;
 		break;
 
             case 12:
-		if(input(motorui::directory, buf = project.getrootdir(),
-		_("root directory: ")) == motorui::yes) {
-                    if(!access(buf.c_str(), F_OK)) {
-			project.setrootdir(buf);
-                    } else {
-                        log(_("Root dir must exist"));
-                    }
-		}
+		log(_("Cannot modify the root directory. Please move the files manually"));
                 break;
 
             case 13:
@@ -1236,12 +1296,12 @@ bool ncursesui::projectsettings() {
 		break;
 
             case 30:
-		trc = projectcontents(pfiles, false);
-		rc = rc || trc;
+		if(projectcontents(pfiles, false))
+		    rc = true;
 		break;
             case 31:
-		trc = projectcontents(pdirs, false);
-		rc = rc || trc;
+		if(projectcontents(pdirs, false))
+		    rc = true;
 		break;
         }
     }
@@ -1256,12 +1316,14 @@ const string &prompt) {
     bool fselmode;
     int fseloptions = 0;
 
+    selwindow.set_title(getcolor(cp_menuhl), _(" <Ins> select; <Space> confirm; <Esc> cancel "));
+
     switch(kind) {
 	case motorui::filechroot:
 	    fseloptions |= FSEL_CHROOT;
+	    fseloptions |= FSEL_MULTI;
 	case motorui::file:
 	    fselmode = true;
-	    selwindow.set_title(getcolor(cp_menuhl), _(" enter to select a file, esc to cancel "));
 	    break;
 
 	case motorui::directorychroot:
@@ -1270,7 +1332,6 @@ const string &prompt) {
 	    fselmode = true;
 	    fseloptions |= FSEL_DIRSELECT;
 	    selector.setstartpoint(result);
-	    selwindow.set_title(getcolor(cp_menuhl), _(" space to select a directory, esc to cancel "));
 	    break;
 
 	case motorui::text:
@@ -1346,7 +1407,7 @@ void ncursesui::populatecontentstree(treeview &tree, motorproject &mp, projedita
 bool ncursesui::projectcontents(projeditaction pea, bool setcurrent) {
     int n, b, citem, id;
     dialogbox db;
-    string buf, head;
+    string buf, head, fname;
     motorfolder *fold;
     motorfile *file;
     motorui::askresult ar;
@@ -1425,16 +1486,23 @@ bool ncursesui::projectcontents(projeditaction pea, bool setcurrent) {
 		}
 
 		if(ar == motorui::yes) {
-		    buf = project.transformfname(projectpaths::relative, buf);
-		    if(find(fold->begin(), fold->end(), buf) == fold->end()) {
-			if(fold->addfile(motorfile(buf), AF_VCS | AF_CHECKDIR | AF_TAKE)) {
-			    tregen = rc = true;
-			    db.redraw();
-			} else {
-			    logf(_("Cannot add ~%s~ to the ~%s~ folder"),
-				buf.c_str(), fold->getname().c_str());
+		    while(!buf.empty()) {
+			fname = getword(buf, "\"");
+			if(!fname.empty()) {
+			    fname = project.transformfname(projectpaths::relative, fname);
+
+    			    if(find(fold->begin(), fold->end(), fname) == fold->end()) {
+				if(fold->addfile(motorfile(fname), AF_VCS | AF_CHECKDIR | AF_TAKE)) {
+				    tregen = rc = true;
+				} else {
+				    logf(_("Cannot add ~%s~ to the ~%s~ folder"),
+					fname.c_str(), fold->getname().c_str());
+				}
+			    }
 			}
 		    }
+
+		    if(tregen) db.redraw();
 		}
 		break;
 	    case 1:
@@ -1460,12 +1528,16 @@ bool ncursesui::projectcontents(projeditaction pea, bool setcurrent) {
 			m = verticalmenu(getcolor(cp_menufr), getcolor(cp_menusel));
 			m.setwindow(
 			    textwindow(db.getwindow()->x2-17,
-				db.getwindow()->y2-2, db.getwindow()->x2+3,
+				db.getwindow()->y2-3, db.getwindow()->x2+3,
 				0, getcolor(cp_menufr)
 			    )
 			);
 			m.additem(_(" Files.."));
 			m.additem(_(" Open the project"));
+/*
+			if(project.getmakemode() == motorproject::automake)
+			    m.additem(_(" Build options.."));
+*/
 			m.scale();
 			n = m.open();
 			m.close();
@@ -1482,6 +1554,10 @@ bool ncursesui::projectcontents(projeditaction pea, bool setcurrent) {
 				rc = false;
 				fin = true;
 				break;
+			    case 3:
+				if(editbuildoptions(*file))
+				    rc = true;
+				break;
 			}
 			break;
 
@@ -1916,6 +1992,13 @@ bool ncursesui::createproject() {
                 project = motorproject(projectname(savename));
 	        onprojectload();
             }
+	} else {
+	    vector<motordist>::const_iterator di;
+	    vector<motordist::distparam>::const_iterator pi;
+
+	    for(di = project.distbegin(); di != project.distend(); ++di)
+	    for(pi = di->parambegin(); pi != di->paramend(); ++pi)
+	        distparams[pi->name] = pi->defval;
 	}
     }
 
@@ -1929,6 +2012,8 @@ void ncursesui::dist() {
     textwindow *wdist;
     dialogbox db;
     vector<motordist>::const_iterator di;
+    vector<motordist::distparam>::const_iterator pi;
+
     verticalmenu mdist(getcolor(cp_menu), getcolor(cp_menusel));
 
     if(project.distbegin() == project.distend()) {
@@ -1945,8 +2030,8 @@ void ncursesui::dist() {
 	mdist.additem(" " + di->getname());
     }
 
-    db.setwindow(wdist = new textwindow(0, 0, DIALOG_WIDTH, 7, getcolor(cp_menufr),
-	TW_CENTERED, getcolor(cp_menuhl), _(" Distribution package parameters ")));
+    db.setwindow(wdist = new textwindow(0, 0, DIALOG_WIDTH, DIALOG_HEIGHT, getcolor(cp_menufr),
+	TW_CENTERED, getcolor(cp_menuhl), _(" Distribution package generation ")));
 
     mdist.setwindow(textwindow(wdist->x1+6, wdist->y1+1, wdist->x1+9+maxl,
 	wdist->y1+2+mdist.getcount(), getcolor(cp_menufr)));
@@ -1969,6 +2054,13 @@ void ncursesui::dist() {
         i = tree.addnode(0, getcolor(cp_menuhl), 0, _(" Out directory "));
         tree.addleaf(i, 0, 0, " " + distdir + " ");
 
+	for(pi = di->parambegin(); pi != di->paramend(); ++pi) {
+	    if(pi == di->parambegin())
+	        i = tree.addnode(0, getcolor(cp_menuhl), 0, _(" Parameters "));
+
+	    tree.addleaff(i, 0, 0, " %s : %s ", pi->title.c_str(), distparams[pi->name].c_str());
+	}
+
         if(first) {
             tree.setcur(fid);
             b = 0;
@@ -1991,12 +2083,20 @@ void ncursesui::dist() {
                 }
 	    } else if(i == 4) {
 		input(motorui::directory, distdir, _("directory to put a dist to: "));
+	    } else if(i > 5) {
+		pi = di->parambegin()+i-6;
+		input(motorui::directory, distparams[pi->name], pi->title + ": ");
 	    }
 	}
     }
 
     db.close();
-    if(r) di->exec(distdir);
+    if(r) {
+	for(map<string, string>::const_iterator mi = distparams.begin(); mi != distparams.end(); ++mi)
+	    executor.setvar(mi->first, mi->second);
+
+	di->exec(distdir);
+    }
 }
 
 void ncursesui::executordone(const string &target, int nerr, int nwarn, int ninfo) {
@@ -2526,8 +2626,17 @@ bool ncursesui::showstack() {
 }
 
 void ncursesui::setdesktop(const vector< pair<string, string> > &asettings) {
+    string afilter, param, buf;
     vector< pair<string, string> >::const_iterator i;
+    vector< pair<char, string> >::const_iterator ik;
+
     watcher.close();
+    distparams.clear();
+
+    for(ik = project.tagnamebegin(); ik != project.tagnameend(); ++ik)
+	afilter += ik->first;
+
+    uitb.setfilter(afilter);
 
     for(i = asettings.begin(); i != asettings.end(); i++) {
 	if(i->first == "ncurses_watchactive") {
@@ -2536,15 +2645,24 @@ void ncursesui::setdesktop(const vector< pair<string, string> > &asettings) {
 	} else if(i->first == "distdir") {
 	    distdir = i->second;
 
+	} else if(i->first.substr(0, 9) == "distparam") {
+	    buf = i->second;
+	    param = getword(buf);
+	    distparams[param] = buf;
+
 	} else if(i->first == "tagbrowser_scope") {
 	    tagbrowser.setscope((motortagbrowser::viewscope)
 		strtoul(i->second.c_str(), 0, 0));
 
+	} else if(i->first == "tagbrowser_filter") {
+	    uitb.setfilter(i->second);
+
 	}
     }
 }
 
 vector< pair<string, string > > ncursesui::getdesktop() const {
+    int pn;
     vector< pair<string, string> > r;
 
     r.push_back(pair<string, string>("ncurses_watchactive",
@@ -2552,6 +2670,11 @@ vector< pair<string, string > > ncursesui::getdesktop() const {
 
     r.push_back(pair<string, string>("distdir", distdir));
     r.push_back(pair<string, string>("tagbrowser_scope", i2str((int) tagbrowser.getscope())));
+    r.push_back(pair<string, string>("tagbrowser_filter", uitb.getfilter()));
+
+    pn = 0;
+    for(map<string, string>::const_iterator ip = distparams.begin(); ip != distparams.end(); ++ip, pn++)
+	r.push_back(make_pair(string("distparam") + i2str(pn), ip->first + " " + ip->second));
 
     return r;
 }
@@ -2571,3 +2694,71 @@ void ncursesui::onprojectload() {
     selector.setstartpoint(project.getrootdir());
     logf(_("Project %s has been loaded"), project.getname().c_str());
 }
+
+motorui::askresult ncursesui::notemplate(string &templname) const {
+    char buf[512];
+    sprintf(buf, _("%s not found, please select template"), templname.c_str());
+    string nt = selecttemplate("", buf);
+
+    if(!nt.empty()) templname = nt; else
+	return cancel;
+
+    return yes;
+}
+
+bool ncursesui::editbuildoptions(motorfile &f) const {
+    dialogbox db;
+    int i, n, b, citem;
+    bool enabled, start;
+    motorfile::build bd = f.getbuild();
+
+    db.setwindow(new textwindow(0, 0, (int) (DIALOG_WIDTH*0.9), (int) (DIALOG_HEIGHT*0.6),
+        getcolor(cp_menufr), TW_CENTERED,
+	getcolor(cp_menuhl), _(" %s build options "),
+	f.getfname().c_str()));
+
+    db.settree(new treeview(getcolor(cp_menu), getcolor(cp_menusel),
+        getcolor(cp_menu), getcolor(cp_menu)));
+
+    db.setbar(new horizontalbar(getcolor(cp_menu),
+        getcolor(cp_menusel), _("Change"), _("Done"), 0));
+
+    treeview &tree = *db.gettree();
+
+    start = false;
+    enabled = !bd.param.empty();
+
+    for(bool fin = false; !fin; ) {
+        tree.clear();
+
+        i = tree.addnode(0, getcolor(cp_menuhl), 0, _(" General "));
+        tree.addleaff(i, 0, 1, _(" Enable optional build : %s "), BOOL_TO_STR(enabled));
+
+	if(enabled) {
+	    i = tree.addnode(0, getcolor(cp_menuhl), 0, _(" Build "));
+	    tree.addleaff(i, 0, 2, _(" Parameter name (--enable-xxx) : %s "), bd.param.c_str());
+	    tree.addleaff(i, 0, 3, _(" Parameter help text : %s "), bd.help.c_str());
+	    tree.addleaff(i, 0, 4, _(" Enabled by default : %s "), BOOL_TO_STR(bd.def));
+	}
+
+	if(!db.open(n, b, (void **) &citem)) break;
+
+	if(!b)
+	switch(citem) {
+	    case 1: enabled = !enabled; break;
+	    case 2: ui.input(motorui::text, bd.param, _("configure parameter name (--enable-xxx): ")); break;
+	    case 3: ui.input(motorui::text, bd.help, _("help text: ")); break;
+	    case 4: bd.def = !bd.def; break;
+	}
+	else {
+	    fin = start = true;
+	}
+    }
+
+    db.close();
+
+    if(start)
+	f.setbuild(bd);
+
+    return start;
+}
