@@ -9,7 +9,7 @@ __MOTOR_BEGIN_NAMESPACE
 
 class uitagbrowser {
     private:
-	string search;
+	string search, filter;
 	textwindow w;
 	verticalmenu m;
 	bool modified;
@@ -17,12 +17,15 @@ class uitagbrowser {
 	vector<motortagbrowser::record> tags;
 
 	static int mkeys(verticalmenu &m, int k);
+	static int multiplekeys(verticalmenu &m, int k);
 
 	void makemenu(verticalmenu &m);
 	void input();
 	bool open(string &fname, int &lineno);
 
 	void changemode();
+	void changefilter();
+
 	void title();
 	void reload();
 
@@ -30,6 +33,9 @@ class uitagbrowser {
 	uitagbrowser();
 	~uitagbrowser();
 
+	string getfilter() const { return filter; }
+	void setfilter(const string &afilter) { filter = afilter; }
+
 	void exec();
 };
 
