@@ -151,13 +151,13 @@ vector< pair<string, motorvcs::changekind> > motorvcs::getchanges() {
     return r;
 }
 
-bool motorvcs::iserror(parserule &apr, const string &msg) {
+bool motorvcs::iserror(parserule *apr, const string &msg) {
     bool r;
     vector<parserule>::iterator i;
 
     if(r = (i = find(parserrors.begin(), parserrors.end(),
     pair<string, string>(msg, ""))) != parserrors.end()) {
-        apr = *i;
+        apr = &*i;
     }
 
     return r;
