@@ -27,7 +27,7 @@ class motorvcs {
 	~motorvcs();
 
 	void putmake(FILE *f, pparamslist *plist);
-	bool iserror(parserule &apr, const string &msg);
+	bool iserror(parserule *apr, const string &msg);
 
 	bool enabled();
 	bool good();
